@@ -16,12 +16,6 @@ pub mod callback_token_verification;
 pub use self::callback_token_verification::CallbackTokenVerification;
 pub mod callback_token_verification_request;
 pub use self::callback_token_verification_request::CallbackTokenVerificationRequest;
-pub mod camera;
-pub use self::camera::Camera;
-pub mod camera_request;
-pub use self::camera_request::CameraRequest;
-pub mod camera_type;
-pub use self::camera_type::CameraType;
 pub mod cloudiot_device;
 pub use self::cloudiot_device::CloudiotDevice;
 pub mod cloudiot_device_request;
@@ -134,8 +128,6 @@ pub mod octoprint_python_request;
 pub use self::octoprint_python_request::OctoprintPythonRequest;
 pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
-pub mod paginated_camera_list;
-pub use self::paginated_camera_list::PaginatedCameraList;
 pub mod paginated_cloudiot_device_list;
 pub use self::paginated_cloudiot_device_list::PaginatedCloudiotDeviceList;
 pub mod paginated_device_calibration_list;
@@ -168,8 +160,6 @@ pub mod paginated_print_nanny_plugin_event_list;
 pub use self::paginated_print_nanny_plugin_event_list::PaginatedPrintNannyPluginEventList;
 pub mod paginated_print_session_list;
 pub use self::paginated_print_session_list::PaginatedPrintSessionList;
-pub mod paginated_printer_controller_list;
-pub use self::paginated_printer_controller_list::PaginatedPrinterControllerList;
 pub mod paginated_printer_profile_list;
 pub use self::paginated_printer_profile_list::PaginatedPrinterProfileList;
 pub mod paginated_public_key_list;
@@ -190,8 +180,6 @@ pub mod patched_alert_bulk_request_request;
 pub use self::patched_alert_bulk_request_request::PatchedAlertBulkRequestRequest;
 pub mod patched_alert_request;
 pub use self::patched_alert_request::PatchedAlertRequest;
-pub mod patched_camera_request;
-pub use self::patched_camera_request::PatchedCameraRequest;
 pub mod patched_cloudiot_device_request;
 pub use self::patched_cloudiot_device_request::PatchedCloudiotDeviceRequest;
 pub mod patched_device_calibration_request;
@@ -204,8 +192,6 @@ pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
 pub mod patched_print_session_request;
 pub use self::patched_print_session_request::PatchedPrintSessionRequest;
-pub mod patched_printer_controller_request;
-pub use self::patched_printer_controller_request::PatchedPrinterControllerRequest;
 pub mod patched_printer_profile_request;
 pub use self::patched_printer_profile_request::PatchedPrinterProfileRequest;
 pub mod patched_public_key_request;
@@ -234,10 +220,6 @@ pub mod print_session;
 pub use self::print_session::PrintSession;
 pub mod print_session_request;
 pub use self::print_session_request::PrintSessionRequest;
-pub mod printer_controller;
-pub use self::printer_controller::PrinterController;
-pub mod printer_controller_request;
-pub use self::printer_controller_request::PrinterControllerRequest;
 pub mod printer_event;
 pub use self::printer_event::PrinterEvent;
 pub mod printer_event_request;
@@ -260,8 +242,6 @@ pub mod remote_control_command;
 pub use self::remote_control_command::RemoteControlCommand;
 pub mod remote_control_command_request;
 pub use self::remote_control_command_request::RemoteControlCommandRequest;
-pub mod software_enum;
-pub use self::software_enum::SoftwareEnum;
 pub mod system_info;
 pub use self::system_info::SystemInfo;
 pub mod system_info_request;
